summaryrefslogtreecommitdiffstats
path: root/sys/kern/kern_clock.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/kern/kern_clock.c')
-rw-r--r--sys/kern/kern_clock.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/kern/kern_clock.c b/sys/kern/kern_clock.c
index 0743c6c..fb4b4a6 100644
--- a/sys/kern/kern_clock.c
+++ b/sys/kern/kern_clock.c
@@ -209,11 +209,11 @@ hardclock(frame)
mtx_unlock_spin(&callout_lock);
/*
* sched_swi acquires sched_lock, so we don't want to call it with
* callout_lock held; incorrect locking order.
*/
if (need_softclock)
- sched_swi(softclock_ih, SWI_NOSWITCH);
+ swi_sched(softclock_ih, SWI_NOSWITCH);
}
/*
OpenPOWER on IntegriCloud
@@ -209,11 +209,11 @@ hardclock(frame)
mtx_unlock_spin(&callout_lock);
/*
- * sched_swi acquires sched_lock, so we don't want to call it with
+ * swi_sched acquires sched_lock, so we don't want to call it with
* callout_lock held; incorrect locking order.
*/